@@ -10,7 +10,6 @@ module Raaz.Core
        , module Raaz.Core.Encode
        , module Raaz.Core.Memory
        , module Raaz.Core.Primitives
-       , module Raaz.Core.Random
        , module Raaz.Core.Types
        , module Raaz.Core.Util
        ) where
@@ -20,7 +19,6 @@ import Raaz.Core.Constants
 import Raaz.Core.Encode
 import Raaz.Core.Memory
 import Raaz.Core.Primitives
-import Raaz.Core.Random
 import Raaz.Core.Types
 import Raaz.Core.Util
 
