@@ -7,7 +7,7 @@ import Data.ByteString.Char8        () -- import IsString instance for
 import Data.String             as E
 import Data.Monoid             as E
 import Data.Word               as E
-import Foreign.Storable        as E (Storable(..))
+import Foreign.Storable        as E (Storable, peek, poke)
 import Test.Hspec              as E
 import Test.Hspec.QuickCheck   as E
 import Test.QuickCheck         as E
@@ -15,5 +15,6 @@ import Test.QuickCheck.Monadic as E
 
 import Raaz.Core               as E hiding ((===), Result)
 import Raaz.Hash               as E
+import Raaz.Hash.Sha1          as E
 import Raaz.Cipher             as E
-import Raaz.Cipher.Internal    as E ( Cipher, unsafeEncrypt, unsafeDecrypt )
+import Raaz.Cipher.Internal    as E ( unsafeEncrypt', unsafeDecrypt', transform' )
